@@ -130,12 +130,12 @@ void Globals::setupLogLevels()
     int index = metaObject()->indexOfEnumerator("LogLevelIds");
     d->logLevelsMetaEnum = metaObject()->enumerator(index);
 
-    d->noLogLevel = new LogLevel(NONE_LOG_LEVEL_ID, i18n("None"), QStringLiteral("help-contents"),
+    d->noLogLevel = new LogLevel(NONE_LOG_LEVEL_ID, i18n("None"), QStringLiteral("edit-none"),
                                  QColor(208, 210, 220));
     d->logLevels.append(d->noLogLevel);
 
     d->debugLogLevel
-        = new LogLevel(DEBUG_LOG_LEVEL_ID, i18n("Debug"), QStringLiteral("attach"), QColor(156, 157, 165));
+        = new LogLevel(DEBUG_LOG_LEVEL_ID, i18n("Debug"), QStringLiteral("debug-run"), QColor(156, 157, 165));
     d->logLevels.append(d->debugLogLevel);
 
     d->informationLogLevel
@@ -144,7 +144,7 @@ void Globals::setupLogLevels()
     d->logLevels.append(d->informationLogLevel);
 
     d->noticeLogLevel
-        = new LogLevel(NOTICE_LOG_LEVEL_ID, i18n("Notice"), QStringLiteral("book2"), QColor(36, 138, 22));
+        = new LogLevel(NOTICE_LOG_LEVEL_ID, i18n("Notice"), QStringLiteral("note"), QColor(36, 138, 22));
     d->logLevels.append(d->noticeLogLevel);
 
     d->warningLogLevel = new LogLevel(WARNING_LOG_LEVEL_ID, i18n("Warning"), QStringLiteral("dialog-warning"),
@@ -152,15 +152,15 @@ void Globals::setupLogLevels()
     d->logLevels.append(d->warningLogLevel);
 
     d->errorLogLevel
-        = new LogLevel(ERROR_LOG_LEVEL_ID, i18n("Error"), QStringLiteral("dialog-close"), QColor(173, 28, 28));
+        = new LogLevel(ERROR_LOG_LEVEL_ID, i18n("Error"), QStringLiteral("dialog-error"), QColor(173, 28, 28));
     d->logLevels.append(d->errorLogLevel);
 
     d->criticalLogLevel
-        = new LogLevel(CRITICAL_LOG_LEVEL_ID, i18n("Critical"), QStringLiteral("exec"), QColor(214, 26, 26));
+        = new LogLevel(CRITICAL_LOG_LEVEL_ID, i18n("Critical"), QStringLiteral("dialog-error"), QColor(214, 26, 26));
     d->logLevels.append(d->criticalLogLevel);
 
     d->alertLogLevel
-        = new LogLevel(ALERT_LOG_LEVEL_ID, i18n("Alert"), QStringLiteral("bell"), QColor(214, 0, 0));
+        = new LogLevel(ALERT_LOG_LEVEL_ID, i18n("Alert"), QStringLiteral("preferences-desktop-notification-bell"), QColor(214, 0, 0));
     d->logLevels.append(d->alertLogLevel);
 
     d->emergencyLogLevel = new LogLevel(EMERGENCY_LOG_LEVEL_ID, i18n("Emergency"),
